@@ -16,19 +16,26 @@
 #' @slot jacc A matrix of Jaccard indexes between each pair of dfMapper nodes
 #' @slot node_data_mat A data.frame with the node size and the average value
 #' of each feature
+#' @slot graph A list containing the igraph object of your Jaccard matrix,
+#' metrics and intermediary objects
+#' @slot clustering A data.frame containing clusters from TDA on nodes and
+#' cells
 #' @return TDAobj class
 #' showClass("TDAobj")
 #' @exportClass TDAobj
 
 setClass("TDAobj",
-         slots = list(orig_data = "data.frame",
-                      scaled_data = "data.frame",
-                      outcomeFact = "data.frame",
-                      outcome = "data.frame",
-                      comp = "data.frame",
-                      dist_mat = "data.frame",
-                      dfMapper = "data.frame",
-                      jacc = "matrix",
-                      node_data_mat = "data.frame"
-         )
+  slots = list(
+    orig_data      = "data.frame",
+    scaled_data    = "data.frame",
+    outcomeFact    = "data.frame",
+    outcome        = "data.frame",
+    comp           = "data.frame",
+    dist_mat       = "matrix",
+    dfMapper       = "data.frame",
+    jacc           = "matrix",
+    node_data_mat  = "data.frame",
+    graph          = "list",
+    clustering     = "list"
+  )
 )
